# Yorkpy

[![PyPI](https://img.shields.io/pypi/v/yorkpy.svg)](https://pypi.org/project/yorkpy/) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/yorkpy.svg)](https://pypi.org/project/yorkpy/) [![PyPI - Wheel](https://img.shields.io/pypi/wheel/yorkpy.svg)](https://pypi.org/project/yorkpy/)

#### Package downloads from the Pypi</b>

[![Downloads](https://pepy.tech/badge/yorkpy)](https://pepy.tech/project/yorkpy)

[![Downloads](https://pepy.tech/badge/yorkpy/month)](https://pepy.tech/project/yorkpy)

[![Downloads](https://pepy.tech/badge/yorkpy/week)](https://pepy.tech/project/yorkpy)
<hr>

## Description 

This R package can be used to analyze performances of cricketers based on match data from Cricsheet. The yorkr package can handle match data from ODIs, Twenty20s and IPL T20s from Cricsheet. The data has to be in yaml format

## Installation 

```py
# Install the package
pip install yorkpy
```
## Importing and Loading Data 

`yorkpy` can be imported using the typical `import`:

```py
# Import yorkpy
import yorkpy
```

To load the data, You could either do specific import


```py
#1.  
import yorkpy.analytics as yka
#yka.matchWormChart(gl_mi,"Mumbai Indians","Gujarat Lions")

```
or import all the functions

```

## References


## R-Package

If you are an R-user, There is an R equivalent of `yorkpy`  [`yorkr`]https://gigadom.in/2016/04/02/introducing-cricket-package-yorkr-part-1-beaten-by-sheer-pace/).

